@@ -1,19 +1,19 @@
 #
-# $Id: Context.pm,v d73612b7334b 2016/04/15 16:10:10 gomor $
+# $Id: Context.pm,v 59b28ae3a2c8 2016/10/06 16:11:23 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
 use warnings;
 
 # Breaking.Feature.Fix
-our $VERSION = '1.22';
+our $VERSION = '1.24';
 our $FIX = '0';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: d73612b7334b $',
+      revision => '$Revision: 59b28ae3a2c8 $',
       tags => [ qw(main core) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
@@ -409,6 +409,8 @@ sub use {
          die("$MSG\n");
       }
 
+      $USE = $__ctx_brik;
+
       my $__ctx_new = $__ctx_module->new(
          context => $CON,
          global => $CON->{global},
@@ -422,8 +424,6 @@ sub use {
          die("$MSG\n");
       }
 
-      $USE = $__ctx_brik;
-
       return $CON->{used}->{$__ctx_brik} = $__ctx_new;
    }, brik => $brik);
 
@@ -439,6 +439,9 @@ sub reuse {
    for my $entry (map { [ $_, $INC{$_} ] } keys %INC) {
       my ($module, $file) = @$entry;
 
+      # Some entries don't have a file (XS related)
+      next unless defined($file);
+
       if ($file eq $INC{"Module/Reload.pm"}) {
          next;   # Too confusing
       }
@@ -660,7 +663,7 @@ sub set {
          if ($@) {
             chomp($@);
             $ERR = 1;
-            my $MSG = "set: Brik [$__ctx_brik] has invalid argument [$__ctx_value]";
+            my $MSG = "set: Brik [$__ctx_brik] has invalid Argument [$__ctx_value]";
             die("$MSG\n");
          }
       }
@@ -673,7 +676,7 @@ sub set {
          if ($@) {
             chomp($@);
             $ERR = 1;
-            my $MSG = "set: Brik [$__ctx_brik] has invalid argument [$__ctx_value]";
+            my $MSG = "set: Brik [$__ctx_brik] has invalid Argument [$__ctx_value]";
             die("$MSG\n");
          }
       }
@@ -788,7 +791,7 @@ sub run {
             if ($@) {
                chomp($@);
                $ERR = 1;
-               my $MSG = "run: Brik [$__ctx_brik] has invalid argument [$_]";
+               my $MSG = "run: Brik [$__ctx_brik] has invalid Argument [$_]";
                die("$MSG\n");
             }
          }
@@ -801,7 +804,7 @@ sub run {
             if ($@) {
                chomp($@);
                $ERR = 1;
-               my $MSG = "run: Brik [$__ctx_brik] has invalid argument [$_]";
+               my $MSG = "run: Brik [$__ctx_brik] has invalid Argument [$_]";
                die("$MSG\n");
             }
          }
