@@ -1,5 +1,5 @@
 #
-# $Id: Global.pm,v d2221083a9e6 2016/04/11 17:10:51 gomor $
+# $Id: Global.pm,v 59b28ae3a2c8 2016/10/06 16:11:23 gomor $
 #
 # core::global Brik
 #
@@ -8,14 +8,14 @@ use strict;
 use warnings;
 
 # Breaking.Feature.Fix
-our $VERSION = '1.22';
+our $VERSION = '1.24';
 our $FIX = '0';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: d2221083a9e6 $',
+      revision => '$Revision: 59b28ae3a2c8 $',
       tags => [ qw(main core) ],
       attributes => { 
          device => [ qw(device) ],
@@ -48,6 +48,9 @@ sub brik_properties {
          exit_on_sigint => 0,
          pid => $$,
       },
+      require_modules => {
+         'File::Path' => [ qw(make_path) ],
+      },
    };
 }
 
@@ -56,11 +59,18 @@ sub brik_use_properties {
 
    my $homedir = $ENV{HOME} || '/tmp';
    my $datadir = $homedir.'/metabrik';
+   my $repository = $homedir.'/metabrik/repository';
+
+   eval("use File::Path qw(make_path);");
+   File::Path::make_path($homedir, $datadir, $repository, {
+      mode => 0755,
+   });
 
    return {
       attributes_default => {
          homedir => $homedir,
          datadir => $datadir,
+         repository => $repository,
       },
    };
 }
