@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v d2221083a9e6 2016/04/11 17:10:51 gomor $
+# $Id: Shell.pm,v 59b28ae3a2c8 2016/10/06 16:11:23 gomor $
 #
 # core::shell Brik
 #
@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 # Breaking.Feature.Fix
-our $VERSION = '1.22';
+our $VERSION = '1.24';
 our $FIX = '0';
 
 use base qw(Term::Shell Metabrik);
@@ -17,7 +17,7 @@ use IO::All;
 
 sub brik_properties {
    return {
-      revision => '$Revision: d2221083a9e6 $',
+      revision => '$Revision: 59b28ae3a2c8 $',
       tags => [ qw(main core) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -44,6 +44,7 @@ sub brik_properties {
          show_all => [ qw(0|1) ],  # Both Attributes and Commands for base and inherited
          aliases_completion => [ qw(0|1) ], # Complete aliases to show original Command
          ps1 => [ qw(prompt) ],
+         capture_mode => [ qw(0|1) ],
          # These are used by Term::Shell
          #path_home => [ qw(directory) ],
          #path_cwd => [ qw(directory) ],
@@ -75,10 +76,12 @@ sub brik_properties {
          show_inherited_all => 0,
          show_all => 0,
          aliases_completion => 0,
+         capture_mode => 1,
       },
       commands => {
          splash => [ ],
          pwd => [ ],
+         full_pwd => [ ],
          get_available_help => [ ],
          get_help_attributes => [ qw(Brik) ],
          get_help_commands => [ qw(Brik) ],
@@ -215,6 +218,19 @@ sub pwd {
    return $self->{path_cwd};
 }
 
+sub full_pwd {
+   my $self = shift;
+
+   my $global = $self->global;
+
+   my $pwd = $self->pwd;
+   my $homedir = $global->homedir;
+
+   $pwd =~ s{^~}{$homedir};
+
+   return $pwd;
+}
+
 sub get_available_help {
    my $self = shift;
 
@@ -262,10 +278,11 @@ sub AUTOLOAD {
    my $context = $self->context;
 
    if ($context->is_used('shell::command')) {
+      my $sc_command = $self->capture_mode ? 'capture' : 'system';
       (my $exec = $command) =~ s/^run_//;
       my $executables = $self->{_executables};
       if (exists($executables->{$exec})) {
-         my $cmd = "run shell::command system $exec";
+         my $cmd = "run shell::command $sc_command $exec";
          return $self->cmd(join(' ', $cmd, @args));
       }
    }
@@ -476,6 +493,20 @@ sub cmd_to_code {
    return $line;
 }
 
+sub cmd {
+   my $self = shift;
+   my ($cmd) = @_;
+
+   # If there is a command like `exit 1', we exit and return the code number
+   if ($cmd =~ m{^\s*exit(?:\s+(\d+))}) {
+      $self->log->verbose("cmd: exiting [$cmd]");
+      $self->run_exit;
+      exit($1);
+   }
+
+   return $self->SUPER::cmd($cmd);
+}
+
 sub process_line {
    my $self = shift;
    my ($line, $lines) = @_;
@@ -504,7 +535,9 @@ sub process_line {
 
    $self->debug && $self->log->debug("process_line: lines[@$lines]");
 
-   $self->cmd(join('', @$lines));
+   my $cmd = join('', @$lines);
+
+   $self->cmd($cmd);
 
    $self->_update_prompt;
 
@@ -597,7 +630,12 @@ sub run_alias {
    }
    elsif (length($alias) && @cmd == 0) {
       $alias =~ s/^run_//;
-      printf("alias %-10s \"%s\"\n", $alias, $aliases->{"run_$alias"});
+      if (exists($aliases->{"run_$alias"})) {
+         printf("alias %-10s \"%s\"\n", $alias, $aliases->{"run_$alias"});
+      }
+      else {
+         $self->log->info("alias: no alias by that name [$alias]");
+      }
 
       return 1;
    }
@@ -1346,8 +1384,9 @@ sub catch_run {
 
    # If it starts with a '/', we really want to 'run shell::command system'
    if ($context->is_used('shell::command')) {
+      my $sc_command = $self->capture_mode ? 'capture' : 'system';
       if (defined($args[0]) && $args[0] =~ m{^\s*/}) {
-         my $cmd = "run shell::command system";
+         my $cmd = "run shell::command $sc_command";
          return $self->cmd(join(' ', $cmd, @args));
       }
    }
